@@ -5,10 +5,10 @@ function (Ns, CheckArguments = TRUE)
     CheckentropartArguments()
   
   NsInt <- as.integer(Ns)
-  if (any(NsInt != Ns)) stop ("The abundance frequency count requires integer abundances")
+  if (any(NsInt != Ns)) warning ("The abundance frequency count requires integer abundances. Abundances have been rounded.")
   
   # Eliminate 0
-  Ns <- Ns[Ns > 0]
+  Ns <- NsInt[NsInt > 0]
   
   DistNs <- tapply(Ns, Ns, length)
   afc <- matrix(c(as.integer(names(DistNs)), DistNs), ncol = 2)
