@@ -34,8 +34,8 @@ function (x, xlab = expression(italic("T")), ylab = NULL, main = NULL, ...)
 summary.PhyloValue <-
 function(object, ...) 
 {
-  cat(object$Function, "applied to", object$Distribution, "along the tree", object$Tree, fill=TRUE)
-  cat("\nResults are", ifelse(object$Normalized, "", "not"), "normalized", fill=TRUE)
+  cat(object$Function, "applied to", object$Distribution, "along the tree:", object$Tree, fill=TRUE)
+  cat("\nResults are", ifelse(object$Normalized, "normalized", "not normalized"), fill=TRUE)
   cat("\nThe average value is:", object$Total)
   cat("\n\nValues along the tree are:\n")
   print(object$Cuts)
